#
# spec file for package libTMCG
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Andreas Stieger <andreas.stieger@gmx.de>
# Copyright (c) 2007 pc2pus <toni@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 12
Name:           libTMCG
Version:        1.3.12
Release:        lp150.1.2
Summary:        C++ library for creating secure and fair online card games
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            https://www.nongnu.org/libtmcg/
Source:         https://download.savannah.gnu.org/releases/libtmcg/%{name}-%{version}.tar.gz
Source2:        https://download.savannah.gnu.org/releases/libtmcg/%{name}-%{version}.tar.gz.sig
Source3:        https://savannah.nongnu.org/project/memberlist-gpgkeys.php?group=libtmcg&download=1#/%{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 4.2
BuildRequires:  libgcrypt-devel >= 1.7.0
BuildRequires:  libgpg-error-devel >= 0.5
BuildRequires:  pkgconfig
Requires:       gmp >= 4.2

%description
LibTMCG is a C++ library for creating secure and fair online card
games. The library contains classes, algorithms, and high-level
protocols to support an application programmer in writing such
software.

%package -n libTMCG%{sover}
Summary:        C++ library for creating secure and fair online card games
Group:          System/Libraries

%description -n libTMCG%{sover}
LibTMCG is a C++ library for creating secure and fair online card
games. The library contains classes, algorithms, and high-level
protocols to support an application programmer in writing such
software. Neither a trusted third party (TTP), i.e. a central game
server, nor trusted hardware components are necessary. With the
library, there is no need for an independent referee, because the
applied protocols provide a basic level of confidentiality and
fairness by itself. The library is suited for peer-to-peer (P2P)
environments where no TTP is available.

It cannot be avoided that malicious players share information about
their private cards, but the protocols ensure that the shuffle of the
deck is performed randomly (presumed that at least one player is
honest) and thus the cards will be distributed uniformly among the
players. Further, no coalition can learn the private cards of a
player against his will (except for trivial conclusions). The
corresponding cryptographic problemis called Mental Poker, and
LibTMCG provides an implementation of such protocols.

The implementation relies on cryptographic techniques---the so-called
zero-knowledge proofs. Using these building blocks, the high-level
protocols minimize the effect of coalitions and preserve the
confidentiality of the players' strategy, i.e. the players are not
required to reveal their cards at the end of the game to show that
they did not cheat.

%package devel
Summary:        Libraries and headers to develop with libTMCG library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description devel
Libraries and headers to develop with the libTMCG library.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%post -n libTMCG%{sover} -p /sbin/ldconfig
%postun -n libTMCG%{sover} -p /sbin/ldconfig
%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -n libTMCG%{sover}
%doc AUTHORS BUGS ChangeLog COPYING NEWS PATENTS THANKS TODO README
%{_libdir}/lib*.so.*

%files devel
%doc AUTHORS BUGS ChangeLog COPYING NEWS PATENTS THANKS TODO README
%{_bindir}/%{name}-config
%{_libdir}/lib*.so
%{_includedir}/*.h*
%{_datadir}/aclocal/%{name}.m4
%{_infodir}/%{name}.info%{ext_info}

%changelog
* Wed Mar 21 2018 kbabioch@suse.com
- Update to 1.3.12:
  * Added function mpz_lprime_prefix() for k-prefix tweak
  * Improved strength of oracle hash function g() by second algo
  * Raised the requirement of libgcrypt version to >= 1.7.0
  * Improved on RFC4880 handling
  * mpz_shash: bugfix changes the output of hash function g()
* Thu Feb  8 2018 kbabioch@suse.com
- Update to 1.3.11:
  * Improved libTMCG initialization (init_libTMCG())
  * Better handling of RFC4880 functionality
- Switched sources to https instead of http
* Sun Jan 21 2018 jengelh@inai.de
- Compact description for size. Outright trim SRPM description.
- Do not ship static libraries.
* Mon Jan 15 2018 kbabioch@suse.com
- update to 1.3.10:
  * Introduced RSA signature generation/verification for OpenPGP
  * Add function for preparing certification signatures
* Sun Jan 14 2018 astieger@suse.com
- update to 1.3.9:
  * fix two minor bugs in the OpenPGP implementation
- includes changes from 1.3.8:
  * The S2K count for OpenPGP private key encryption has been
    increased to a reasonable value
- includes changes from 1.3.7, 1.3.6, 1.3.5:
  * minor bug fixes
- includes changes from 1.3.4:
  * DKG tools removed, deparate project DKGPG
- includes changes from 1.3.3:
  * Small enhancements for DKG tools
- includes changes from 1.3.2:
  * Major improvements for distributed key generation (DKG) and
    threshold cryptography
* Fri May 26 2017 astieger@suse.com
- update to 1.3.1:
  * VSSHE: added a simple variant of SetupGenerators_publiccoin()
  * DKG: use very strong randomness from libgcrypt (long term keys)
  * RFC4880: added implementation of Partial Body Lengths
* Wed May 17 2017 astieger@suse.com
- update to 1.3.0:
  * remove some issues found by coverity scan
  * add undocumented protocols and experimental support for
    distributed key generation
  * Verifiable setup of VTMF group generator
  * For some advanced protocols (e.g. Groth's shuffle) with more
    than two parties the distributed coin flipping protocol (EDCF)
    should be used.
- includes changes from 1.2.0:
  * The default security parameters have been updated to current
    state of the art
  * The complexity of hash function g() was improved
  * Non-interactive versions of the verifiable shuffle resp.
    rotation protocol provide more efficient instantiations with
    soundness based on the well-known Fiat-Shamir heuristic
  * stengthen interactive versions of the protocols against
    malicious verifiers by coin flipping between prover and
    verifier
  * include  protocol for reliable broadcast
  * improved documentation
- includes changes from 1.1.3:
  * VRHE scheme provides an efficient HVZK argument for cyclic
    shuffle
- includes changes from 1.1.2:
  * Small bugfixes have been applied in order to compile with gcc
    4.3.x
* Sun Jan 25 2015 andreas.stieger@gmx.de
- verify source signature
* Sat Mar 31 2012 andreas.stieger@gmx.de
- update to 1.1.2
- fix most warnings and errors for current openSUSE standards
* Thu May 10 2007 toni@links2linux.de
- Initial package 1.1.1
